@@ -1,6 +1,7 @@
 from django.conf import settings
 from django.contrib import admin, messages
 from django.contrib.admin import ModelAdmin
+from django.contrib.auth.forms import ReadOnlyPasswordHashWidget
 from django.utils.translation import gettext_lazy as _
 
 from django_seriously.authtoken.models import Token
@@ -14,7 +15,6 @@ class TokenAdmin(ModelAdmin):
         "name",
         "scopes",
     )
-    readonly_fields = ("id", "key")
 
     def save_model(self, request, obj: Token, form, change):
         if not change:
@@ -30,6 +30,18 @@ class TokenAdmin(ModelAdmin):
             obj.key = token.key
         return super().save_model(request, obj, form, change)
 
+    def get_readonly_fields(self, request, obj=None):
+        if not obj:
+            # handle ReadOnlyPasswordHashWidget RO hack
+            return ("key",)
+        else:
+            return "id", "created_at", "updated_at"
+
+    def formfield_for_dbfield(self, db_field, **kwargs):
+        if db_field.name == "key":
+            kwargs["widget"] = ReadOnlyPasswordHashWidget
+        return super().formfield_for_dbfield(db_field, **kwargs)
+
 
 if "django_seriously.authtoken" in settings.INSTALLED_APPS:
     admin.site.register(Token, TokenAdmin)
